__author__ = 'Derek Payton <derek.payton@gmail.com>'
__copyright__ = 'Copyright (c) Derek Payton'
__description__ = 'A fake Django admin login screen to notify admins of attempted unauthorized access.'
__version__ = '0.2.3'
__license__ = 'MIT License'
